@@ -8,10 +8,12 @@
 # Anything you might import from outside foolscap.api is subject to movement
 # in new releases.
 
-from foolscap._version import verstr as __version__
+from foolscap._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
 
-# here are the primary entry points
-from foolscap.pb import Tub, UnauthenticatedTub
+# here is the primary entry point
+from foolscap.pb import Tub
 
 # names we import so that others can reach them as foolscap.api.foo
 from foolscap.remoteinterface import RemoteInterface
@@ -30,7 +32,7 @@ from foolscap.logging import app_versions
 # hush pyflakes
 _unused = [
     __version__,
-    Tub, UnauthenticatedTub,
+    Tub,
     RemoteInterface,
     Referenceable, SturdyRef,
     Copyable, RemoteCopy, registerRemoteCopy,
