@@ -12,7 +12,7 @@ from twisted.application import service, internet
 from foolscap.api import Tub, Referenceable
 from foolscap.logging.interfaces import RILogGatherer, RILogObserver
 from foolscap.logging.incident import IncidentClassifierBase, TIME_FORMAT
-from foolscap.util import get_local_ip_for
+from foolscap.util import get_local_ip_for, move_into_place
 
 class BadTubID(Exception):
     pass
@@ -21,7 +21,6 @@ class GatheringBase(service.MultiService, Referenceable):
     # requires self.furlFile and self.tacFile to be set on the class, both of
     # which should be relative to the basedir.
     use_local_addresses = True
-    tub_class = Tub
 
     def __init__(self, basedir):
         if basedir is None:
@@ -38,7 +37,7 @@ class GatheringBase(service.MultiService, Referenceable):
     def startService(self):
         service.MultiService.startService(self)
         certFile = os.path.join(self.basedir, "gatherer.pem")
-        self._tub = self.tub_class(certFile=certFile)
+        self._tub = Tub(certFile=certFile)
         self._tub.setServiceParent(self)
         local_addresses = ["127.0.0.1"]
         local_address = get_local_ip_for()
@@ -53,7 +52,9 @@ class GatheringBase(service.MultiService, Referenceable):
         l = self._tub.listenOn("tcp:%d" % desired_portnum)
 
         got_portnum = l.getPortnum()
-        open(portnumfile, "w").write("%d\n" % got_portnum)
+        f = open(portnumfile, "w")
+        f.write("%d\n" % got_portnum)
+        f.close()
 
         # we can't do setLocation until we have two things:
         #  portnum: this requires listenOn, if portnum=0 also startService
@@ -191,7 +192,7 @@ class GathererService(GatheringBase):
         to_time = self.format_time(now)
         new_name = "from-%s---to-%s.flog" % (from_time, to_time)
         new_name = os.path.join(self.basedir, new_name)
-        os.rename(self._savefile_name, new_name)
+        move_into_place(self._savefile_name, new_name)
         self._open_savefile(now)
         if self.bzip:
             # we spawn an external bzip process because it's easier than
@@ -467,8 +468,8 @@ class IncidentGathererService(GatheringBase, IncidentClassifierBase):
 
     def remote_logport(self, nodeid, publisher):
         # we ignore nodeid (which is a printable string), and get the tubid
-        # (or its <unauth> name) from the publisher remoteReference.
-        # getRemoteTubID() protects us from .. and / and other nasties.
+        # from the publisher remoteReference. getRemoteTubID() protects us
+        # from .. and / and other nasties.
         tubid_s = publisher.getRemoteTubID()
         basedir = os.path.join(self.basedir, "incidents", tubid_s)
         stdout = self.stdout or sys.stdout
