@@ -285,9 +285,9 @@ class RemoteReferenceTracker(object):
         # not yet positive it would work.. how exactly does the base url get
         # sent, anyway? What about Tubs visible through multiple names?
         self.url = url
-        if url is not None and self.broker.remote_tubref:
-            # unit tests frequently set url=None, and UnauthenticatedTubs
-            # don't have a remote_tubref
+        if url is not None:
+            # unit tests frequently set url=None
+            assert self.broker.remote_tubref
             expected_tubid = self.broker.remote_tubref.getTubID()
             url_tubid = SturdyRef(url).getTubRef().getTubID()
             if expected_tubid != url_tubid:
@@ -349,9 +349,8 @@ class RemoteReferenceOnly(object):
         return SturdyRef(self.tracker.getURL())
     def getRemoteTubID(self):
         rt = self.tracker.broker.remote_tubref
-        if rt:
-            return rt.getTubID()
-        return "<unauth>"
+        assert rt
+        return rt.getTubID()
 
     def getPeer(self):
         """Return an IAddress-providing object that describes the remote
@@ -771,7 +770,6 @@ class BadFURLError(Exception):
     pass
 
 AUTH_STURDYREF_RE = re.compile(r"pb://([^@]+)@([^/]*)/(.+)$")
-NONAUTH_STURDYREF_RE = re.compile(r"pbu://([^/]*)/(.+)$")
 
 # This can match IPv4 IP addresses + port numbers *or* host names +
 # port numbers.
@@ -787,9 +785,116 @@ def encode_location_hint(hint):
     host, port = hint[1:]
     return "%s:%d" % (host, port)
 
+# _tokenize(), _parse() and _parseClientTCP() are copied from
+# twisted.internet.endpoints
+
+_OP, _STRING = range(2)
+
+def _tokenize(description):
+    """
+    Tokenize a strports string and yield each token.
+
+    @param description: a string as described by L{serverFromString} or
+        L{clientFromString}.
+
+    @return: an iterable of 2-tuples of (L{_OP} or L{_STRING}, string).  Tuples
+        starting with L{_OP} will contain a second element of either ':' (i.e.
+        'next parameter') or '=' (i.e. 'assign parameter value').  For example,
+        the string 'hello:greet\=ing=world' would result in a generator
+        yielding these values::
+
+            _STRING, 'hello'
+            _OP, ':'
+            _STRING, 'greet=ing'
+            _OP, '='
+            _STRING, 'world'
+    """
+    current = ''
+    ops = ':='
+    nextOps = {':': ':=', '=': ':'}
+    description = iter(description)
+    for n in description:
+        if n in ops:
+            yield _STRING, current
+            yield _OP, n
+            current = ''
+            ops = nextOps[n]
+        elif n == '\\':
+            current += description.next()
+        else:
+            current += n
+    yield _STRING, current
+
+def _parse(description):
+    """
+    Convert a description string into a list of positional and keyword
+    parameters, using logic vaguely like what Python does.
+
+    @param description: a string as described by L{serverFromString} or
+        L{clientFromString}.
+
+    @return: a 2-tuple of C{(args, kwargs)}, where 'args' is a list of all
+        ':'-separated C{str}s not containing an '=' and 'kwargs' is a map of
+        all C{str}s which do contain an '='.  For example, the result of
+        C{_parse('a:b:d=1:c')} would be C{(['a', 'b', 'c'], {'d': '1'})}.
+    """
+    args, kw = [], {}
+    def add(sofar):
+        if len(sofar) == 1:
+            args.append(sofar[0])
+        else:
+            kw[sofar[0]] = sofar[1]
+    sofar = ()
+    for (type, value) in _tokenize(description):
+        if type is _STRING:
+            sofar += (value,)
+        elif value == ':':
+            add(sofar)
+            sofar = ()
+    add(sofar)
+    return args, kw
+
+def _parseClientTCP(*args, **kwargs):
+    """
+    Perform any argument value coercion necessary for TCP client parameters.
+
+    Valid positional arguments to this function are host and port.
+
+    Valid keyword arguments to this function are all L{IReactorTCP.connectTCP}
+    arguments.
+
+    @return: The coerced values as a C{dict}.
+    """
+
+    if len(args) == 2:
+        kwargs['port'] = int(args[1])
+        kwargs['host'] = args[0]
+    elif len(args) == 1:
+        if 'host' in kwargs:
+            kwargs['port'] = int(args[0])
+        else:
+            kwargs['host'] = args[0]
+
+    try:
+        kwargs['port'] = int(kwargs['port'])
+    except KeyError:
+        pass
+
+    try:
+        kwargs['timeout'] = int(kwargs['timeout'])
+    except KeyError:
+        pass
+
+    try:
+        kwargs['bindAddress'] = (kwargs['bindAddress'], 0)
+    except KeyError:
+        pass
+
+    return kwargs
+
 # Each location hint must start with "TYPE:" (where TYPE is alphanumeric) and
 # then can contain any characters except "," and "/". These are expected to
-# look like Twisted endpoin descriptors, or contain other ":"-separated
+# look like Twisted endpoint descriptors, or contain other ":"-separated
 # fields (e.g. "TYPE:key=value:key=value" or "TYPE:stuff:morestuff"). We also
 # accept old-syle implicit TCP hints (host:port). To avoid being interpreted
 # as an old-style hint, the part after TYPE: may not consist of only 1-5
@@ -800,7 +905,10 @@ def encode_location_hint(hint):
 # of hints:
 #
 #  HOST:PORT                 (implicit tcp)
-#  tcp:host=HOST:port=POST   (endpoint syntax for TCP connections)
+#  tcp:host=HOST:port=PORT }
+#  tcp:HOST:PORT           } (endpoint syntax for TCP connections
+#  tcp:host=HOST:PORT      }  in full, compact and mixed forms)
+#  tcp:HOST:port=PORT      }
 
 def decode_location_hints(hints_s):
     hints = []
@@ -815,10 +923,12 @@ def decode_location_hints(hints_s):
                 hint = ( "tcp", mo.group(1), int(mo.group(2)) )
                 hints.append(hint)
             else:
-                pieces = hint_s.split(':')
-                if pieces[0] == 'tcp':
-                    fields = dict([f.split("=") for f in pieces[1:]])
-                    hint = ("tcp", fields["host"], int(fields["port"]))
+                args, kwargs = _parse(hint_s)
+                aname = args.pop(0)
+                name = aname.upper()
+                if name == 'TCP':
+                    fields = _parseClientTCP(*args, **kwargs)
+                    hint = ("tcp", fields["host"], fields["port"])
                     hints.append(hint)
                 else:
                     # Ignore other things from the future.
@@ -826,19 +936,15 @@ def decode_location_hints(hints_s):
     return hints
 
 def decode_furl(furl):
-    """Returns (encrypted, tubID, location_hints, name)"""
+    """Returns (tubID, location_hints, name)"""
     # pb://key@{ip:port,host:port,[ipv6]:port}[/unix]/swissnumber
     # i.e. pb://tubID@{locationHints..}/name
     #
     # it can live at any one of a (TODO) variety of network-accessible
     # locations, or (TODO) at a single UNIX-domain socket.
-    #
-    # there is also an unauthenticated form, which does not have a TubID
 
     mo_auth_furl = AUTH_STURDYREF_RE.search(furl)
-    mo_nonauth_furl = NONAUTH_STURDYREF_RE.search(furl)
     if mo_auth_furl:
-        encrypted = True
         # we only pay attention to the first 32 base32 characters
         # of the tubid string. Everything else is left for future
         # extensions.
@@ -850,24 +956,14 @@ def decode_furl(furl):
         location_hints = decode_location_hints(hints)
         name = mo_auth_furl.group(3)
 
-    elif mo_nonauth_furl:
-        encrypted = False
-        tubID = None
-        hints = mo_nonauth_furl.group(1)
-        location_hints = decode_location_hints(hints)
-        name = mo_nonauth_furl.group(2)
-
     else:
         raise ValueError("unknown FURL prefix in %r" % (furl,))
-    return (encrypted, tubID, location_hints, name)
+    return (tubID, location_hints, name)
 
-def encode_furl(encrypted, tubID, location_hints, name):
+def encode_furl(tubID, location_hints, name):
     location_hints_s = ",".join([encode_location_hint(hint)
                                  for hint in location_hints])
-    if encrypted:
-        return "pb://" + tubID + "@" + location_hints_s + "/" + name
-    else:
-        return "pbu://" + location_hints + "/" + name
+    return "pb://" + tubID + "@" + location_hints_s + "/" + name
 
 
 class SturdyRef(Copyable, RemoteCopy):
@@ -885,7 +981,6 @@ class SturdyRef(Copyable, RemoteCopy):
 
     typeToCopy = copytype = "foolscap.SturdyRef"
 
-    encrypted = False
     tubID = None
     name = None
 
@@ -893,13 +988,10 @@ class SturdyRef(Copyable, RemoteCopy):
         self.locationHints = [] # list of (type, host, port) tuples
         self.url = url
         if url:
-            self.encrypted, self.tubID, self.locationHints, self.name = \
-                decode_furl(url)
+            self.tubID, self.locationHints, self.name = decode_furl(url)
 
     def getTubRef(self):
-        if self.encrypted:
-            return TubRef(self.tubID, self.locationHints)
-        return NoAuthTubRef(self.locationHints)
+        return TubRef(self.tubID, self.locationHints)
 
 
     def getURL(self):
@@ -910,13 +1002,9 @@ class SturdyRef(Copyable, RemoteCopy):
 
     def _distinguishers(self):
         """Two SturdyRefs are equivalent if they point to the same object.
-        SturdyRefs to encrypted Tubs only pay attention to the TubID and the
-        reference name. SturdyRefs to unauthenticated Tubs must use the
-        location hints instead of the (missing) TubID. This method makes it
-        easier to compare a pair of SturdyRefs."""
-        if self.encrypted:
-            return (True, self.tubID, self.name)
-        return (False, self.locationHints, self.name)
+        SturdyRefs pay attention only to the TubID and the reference name.
+        This method makes it easier to compare a pair of SturdyRefs."""
+        return (True, self.tubID, self.name)
 
     def __hash__(self):
         return hash(self._distinguishers())
@@ -930,7 +1018,6 @@ class TubRef(object):
     """This is a little helper class which provides a comparable identifier
     for Tubs. TubRefs can be used as keys in dictionaries that track
     connections to remote Tubs."""
-    encrypted = True
 
     def __init__(self, tubID, locationHints=None):
         self.tubID = tubID
@@ -957,26 +1044,3 @@ class TubRef(object):
         return (cmp(type(self), type(them)) or
                 cmp(self.__class__, them.__class__) or
                 cmp(self._distinguishers(), them._distinguishers()))
-
-class NoAuthTubRef(TubRef):
-    # this is only used on outbound connections
-    encrypted = False
-
-    def __init__(self, locations):
-        self.locations = locations
-
-    def getLocations(self):
-        return self.locations
-
-    def getTubID(self):
-        return "<unauth>"
-    def getShortTubID(self):
-        return "<unauth>"
-
-    def __str__(self):
-        return "pbu://" + ",".join([encode_location_hint(location)
-                                    for location in self.locations])
-
-    def _distinguishers(self):
-        """This serves the same purpose as SturdyRef._distinguishers."""
-        return tuple(self.locations)
